@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2017-01-09'; # DATE
-our $VERSION = '0.42'; # VERSION
+our $DATE = '2017-01-10'; # DATE
+our $VERSION = '0.43'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,6 +13,7 @@ use Data::Dmp;
 use JSON::MaybeXS ();
 use Module::CoreList::More;
 use Module::Path::More qw(module_path);
+use Perinci::Sub::Util qw(err);
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(gen_inline_pericmd_script);
@@ -753,6 +754,11 @@ https://www.debian.org/doc/debian-policy/ch-source.html#s-embeddedfiles ).
 
 _
         },
+        pod => {
+            summary => 'Whether to generate POD for the script',
+            schema => ['bool*', is=>1],
+            default => 1,
+        },
 
         output_file => {
             summary => 'Set output file, defaults to stdout',
@@ -1136,6 +1142,28 @@ _
             }
         }
 
+        my $pod;
+        if ($args{pod} // 1) {
+            require Perinci::CmdLine::POD;
+            my $res = Perinci::CmdLine::POD::gen_pod_for_pericmd_script(
+                url                => $args{url},
+                program_name       => $cd->{script_name},
+                summary            => $args{script_summary},
+                common_opts        => $cd->{copts},
+                subcommands        => $args{subcommands},
+                default_subcommand => $args{default_subcommand},
+                per_arg_json       => 1,
+                per_arg_yaml       => 0,
+                read_env           => 0, # TODO
+                #env_name           => $args{env_name}, TODO
+                read_config        => 0, # TODO
+                #config_filename    => $args{config_filenames},
+                #config_dirs        => $args{config_dirs},
+            );
+            return err($res, 500, "Can't generate POD") unless $res->[0] == 200;
+            $pod = $res->[2];
+        }
+
         # generate final result
         $cd->{result} = join(
             "",
@@ -1202,6 +1230,8 @@ _
 
             @l,
 
+            defined $pod ? ("=pod\n\n", "=encoding UTF-8\n\n", $pod, "\n\n=cut\n\n") : (),
+
             $dp_code2,
 
             ("### code_after_end\n", $args{code_after_end}, "\n") x !!$args{code_after_end},
@@ -1256,7 +1286,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.42 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-09.
+This document describes version 0.43 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-10.
 
 =head1 SYNOPSIS
 
@@ -1448,6 +1478,10 @@ https://www.debian.org/doc/debian-policy/ch-source.html#s-embeddedfiles ).
 
 Whether to pass Perinci::CmdLine::Inline object.
 
+=item * B<pod> => I<bool> (default: 1)
+
+Whether to generate POD for the script.
+
 =item * B<read_config> => I<any>
 
 Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
